<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/include/language/en_us.lang.php,v 1.68 2005/04/26 06:50:39 rank Exp $
 * Description:  Defines the German language pack for the base application.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 ********************************************************************************/
$app_strings = array(
'LBL_BROWSER_TITLE' => 'vtiger CRM 5 - Commercial Open Source CRM',
'LBL_MY_ACCOUNT'=>'Mein Konto',
'LBL_MY_PREFERENCES'=>'Meine Einstellungen',
'LBL_ADMIN'=>'Admin',
'LBL_LOGOUT'=>'Abmelden',
'LBL_SEARCH'=>'Suchen',
'LBL_LAST_VIEWED'=>'Zuletzt betrachtet',
'LBL_TODAY'=>'Heute',
'LBL_ALL'=>'Alle',
'LBL_SHOW'=>'zeige:',
'today'=>"heutige",
'all'=>'Alle',
'LBL_UPCOMING_EVENTS'=>'aktuelle Aktivitäten',
'LBL_PENDING_EVENTS'=>'überfällige Aktivitäten',
'NTC_WELCOME_MESSAGE'=>"Willkommen!",
'NTC_DESCRIPTION'=>"Kein gülter Benutzername und / oder Passwort für die Anmeldung.",
'NTC_WELCOME'=>'Willkommen',
'NTC_NO_ITEMS_DISPLAY'=>'keine',
'LBL_OR'=>'oder',
'LBL_ALT_HOT_KEY'=>'Alt+',
'LBL_SAVE_LABEL'=>'Speichern',
'LBL_REPLACE_LABEL' => 'Ersetzen',
'LBL_APPLY_BUTTON_LABEL' => 'Anwenden',
'LBL_SEND_MAIL_BUTTON'=>'E-Mail senden',
'LBL_SAVE_BUTTON_TITLE'=>'Speichern [Alt+S]',
'LBL_EDIT_BUTTON_TITLE'=>'Bearbeiten [Alt+E]',
'LBL_CONVERTSO_BUTTON_TITLE'=>'erstelle Kundenbestellung',
'LBL_CONVERTINVOICE_BUTTON_TITLE'=>'Rechnung erstellen',
'LBL_EDIT_BUTTON'=>'Bearbeiten',
'LBL_DUPLICATE_BUTTON_TITLE'=>'Kopieren [Alt+U]',
'LBL_DUPLICATE_BUTTON'=>'Kopieren',
'LBL_TABCUSTOMISE_BUTTON_TITLE'=>'Anpassen [Alt+C]',
'LBL_FORUM_HIDE_BUTTON_TITLE'=>'Forum verbergen [Alt+I]',
'LBL_FORUM_HIDE_BUTTON_KEY'=>'H',
'LBL_FORUM_SHOW_BUTTON_TITLE'=>'Forum zeigen [Alt+W]',
'LBL_FORUM_SHOW_BUTTON_KEY'=>'W',
'LBL_TABCUSTOMISE_BUTTON'=>'Anpassen',
'LBL_DELETE_BUTTON_TITLE'=>'Löschen [Alt+D]',
'LBL_DELETE_BUTTON'=>'Löschen',
'LBL_FIND_BUTTON'=>'Los',
'LBL_CONVERT_BUTTON_TITLE'=>'Umwandeln [Alt+C]',
'LBL_CONVERT_BUTTON_KEY'=>'C',
'LBL_CONVERT_BUTTON_LABEL'=>'Lead umwandeln',
'LBL_TABCUSTOMISE_BUTTON_KEY'=>'C',
'LBL_TABCUSTOMISE_BUTTON_LABEL'=>'Register anpassen',
'LBL_ROLES_BUTTON_LABEL'=>'Rollen zeigen',
'LBL_LISTROLES_BUTTON_LABEL'=>'Rollen zeigen',
'LBL_FORUM_HIDE_BUTTON_LABEL'=>'Forum verbergen',
'LBL_FORUM_SHOW_BUTTON_LABEL'=>'Forum zeigen',
'LBL_NEW_BUTTON_TITLE'=>'Neu [Alt+N]',
'LBL_CHANGE_BUTTON_TITLE'=>'Ändern [Alt+G]',
'LBL_CANCEL_BUTTON_TITLE'=>'Abbrechen [Alt+X]',
'LBL_SEARCH_BUTTON_TITLE'=>'Suchen [Alt+Q]',
'LBL_CLEAR_BUTTON_TITLE'=>'Leeren [Alt+C]',
'LBL_SELECT_BUTTON_TITLE'=>'Wählen [Alt+T]',
'LBL_CREATE_BUTTON_LABEL' =>'Erstelle',
'LBL_GENERATE'=>'Erstelle',
'LBL_SAVE_BUTTON_KEY'=>'S',
'LBL_EDIT_BUTTON_KEY'=>'E',
'LBL_CONVERTSO_BUTTON_KEY'=>'S',
'LBL_CONVERTINVOICE_BUTTON_KEY'=>'I',
'LBL_DUPLICATE_BUTTON_KEY'=>'U',
'LBL_DELETE_BUTTON_KEY'=>'D',
'LBL_NEW_BUTTON_KEY'=>'N',
'LBL_CHANGE_BUTTON_KEY'=>'G',
'LBL_CANCEL_BUTTON_KEY'=>'X',
'LBL_SEARCH_BUTTON_KEY'=>'Q',
'LBL_CLEAR_BUTTON_KEY'=>'C',
'LBL_SELECT_BUTTON_KEY'=>'T',
'LBL_SAVE_BUTTON_LABEL'=>'Speichern',
'LBL_EDIT_BUTTON_LABEL'=>'Bearbeiten',
'LBL_CONVERTSO_BUTTON_LABEL'=>'erstelle Kundenbestellung',
'LBL_CONVERTINVOICE_BUTTON_LABEL'=>'erstelle Rechnung',
'LBL_DUPLICATE_BUTTON_LABEL'=>'Kopieren',
'LBL_DELETE_BUTTON_LABEL'=>'Löschen',
'LBL_NEW_BUTTON_LABEL'=>'Neu',
'LBL_CHANGE_BUTTON_LABEL'=>'Wähle',
'LBL_CANCEL_BUTTON_LABEL'=>'Abbrechen',
'LBL_SEARCH_BUTTON_LABEL'=>'Suchen',
'LBL_CLEAR_BUTTON_LABEL'=>'Leeren',
'LBL_SELECT_BUTTON_LABEL'=>'Wähle',
'LBL_SELECT_CONTACT_BUTTON_TITLE'=>'Person wählen [Alt+T]',
'LBL_SELECT_CONTACT_BUTTON_KEY'=>'T',
'LBL_SELECT_CONTACT_BUTTON_LABEL'=>'Person wählen',
'LBL_SELECT_CAMPAIGN_BUTTON_LABEL'=>'Kampagne wählen',
'LBL_SELECT_USER_BUTTON_TITLE'=>'Benutzer wählen [Alt+U]',
'LBL_SELECT_USER_BUTTON_KEY'=>'U',
'LBL_SELECT_USER_BUTTON_LABEL'=>'Benutzer',
'LBL_SETTINGS'=>'Einstellungen',
'LBL_LIST_USERIP'=>'Benutzer IP',
'LBL_LIST_SIGNIN'=>'angemeldet',
'LBL_LIST_SIGNOUT'=>'abgemeldet',
'LBL_LIST_STATUS'=>'Status',
'LBL_LIST_NAME'=>'Name',
'LBL_LIST_USER_NAME'=>'Benutzer',
'LBL_LIST_EMAIL'=>'E-Mail',
'LBL_LIST_PHONE'=>'Telefon',
'LBL_LIST_CONTACT_NAME'=>'Person',
'LBL_LIST_ACCOUNT_NAME'=>'Organisation',
'LBL_USER_LIST'=>'Nutzerliste',
'LBL_CONTACT_LIST'=>'Personenliste',
'LBL_LNK_SETTINGS'=> 'Einstellungen',
'LNK_IMPORT_LEADS'=>'Importiere Leads',
'LBL_LOCATE_MAP'=>'Adresse auf Karte anzeigen',
'LBL_ADDRESS' => 'Adresse',
'LBL_ADD_TAG'=>'Tag hinzufügen',
'LBL_TAG_IT'=>'setze Tag',
'LBL_CLOSE'=>'Schließen',
'LNK_ADVANCED_SEARCH'=>'erweiterte Suche',
'LNK_BASIC_SEARCH'=>'einfache Suche',
'LNK_EDIT'=>'edit',
'LNK_REMOVE'=>'entf',
'LNK_DELETE'=>'lö',
'LNK_LIST_START'=>'Anfang',
'LNK_LIST_NEXT'=>'weiter',
'LNK_LIST_PREVIOUS'=>'vorherige',
'LNK_LIST_END'=>'Ende',
'LBL_LIST_OF'=>'von',
'LNK_PRINT'=>'Drucken',
'LNK_HELP'=>'Hilfe',
'LNK_VTDOCS'=>'vtiger Doku',
'LNK_ABOUT'=>'Über',
'LNK_OUTLOOK'=>'./include/images/outlook_download.gif',
'SINGLE_Accounts' => 'Organisation',
'SINGLE_Contacts' => 'Person',
'SINGLE_Campaigns' => 'Kampagne',
'SINGLE_HelpDesk' => 'Ticket',
'SINGLE_Leads' => 'Lead',
'SINGLE_Events' => 'Ereignis',
'SINGLE_Calendar' => 'Aufgabe',
'SINGLE_Dashboard' => 'Cockpit',
'SINGLE_Emails' => 'E-Mail',
'SINGLE_Faq' => 'Wissensbasis',
'SINGLE_Home' => 'Startseite',
'SINGLE_Invoice' => 'Rechnung',
'SINGLE_Potentials' => 'Potential',
'SINGLE_Products' => 'Produkt',
'SINGLE_Vendors' => 'Lieferant',
'SINGLE_PriceBooks' => 'Preisliste',
'SINGLE_Quotes' => 'Angebot',
'SINGLE_PurchaseOrder' => 'Einkaufsbestellung',
'SINGLE_SalesOrder' => 'Verkaufsbestellung',
'SINGLE_Rss' => 'RSS',
'SINGLE_Reports' => 'Bericht',
'SINGLE_Portal' => 'Portal',
'SINGLE_Webmails' => 'Webmail',
'SINGLE_Users' => 'Nutzer',
'NEW' => 'erstelle',
'NTC_REQUIRED' => 'Pflichtfelder',
'LBL_REQUIRED_SYMBOL'=>'*',
'LBL_CURRENCY_SYMBOL'=>'EUR',
'LBL_THOUSANDS_SYMBOL'=>'k',
'NTC_DATE_FORMAT'=>'(dd-mm-yyyy)',
'NTC_TIME_FORMAT'=>'(24:00)',
'NTC_DATE_TIME_FORMAT'=>'(dd-mm-yyyy 24:00)',
'NTC_DELETE_CONFIRMATION'=>'Wollen Sie diesen Eintrag löschen?',
'NTC_ACCOUNT_DELETE_CONFIRMATION' => 'Wenn Sie diese Organisation löschen, werden auch die darauf bezogenen Einträge in den Potentialen und Angeboten gelöscht. Sind Sie sicher, dass Sie diese Organisation wirklich löschen wollen?',
'NTC_VENDOR_DELETE_CONFIRMATION' => 'Wenn Sie diese Organisation löschen, werden auch die darauf bezogenen Einträge in den Einkaufsbestellungen gelöscht. Sind Sie sicher, dass Sie diesen Lieferanten wirklich löschen wollen?',
'ERR_DELETE_RECORD'=>'Zum Löschen muss mindestens ein Eintrag markiert sein.',
'ERR_CREATING_TABLE'=>'Fehler beim Erstellen der Tabelle: ',
'ERR_CREATING_FIELDS'=>'Fehler beim Ausfüllen der zusätzlichen Felder: ',
'ERR_MISSING_REQUIRED_FIELDS'=>'Fehlende Pflichtangaben:',
'ERR_INVALID_EMAIL_ADDRESS'=>'ist keine gültige E-Mail Adresse.',
'ERR_INVALID_YAHOO_EMAIL_ADDRESS' => 'ist keine gültige Yahoo E-Mail Adresse.',
'ERR_INVALID_DATE_FORMAT'=>'Das Datumsformat muss lauten: jj-mm-tt',
'ERR_INVALID_MONTH'=>'Bitte einen gültigen Monat eingeben.',
'ERR_INVALID_DAY'=>'Bitte einen gültigen Tag eingeben.',
'ERR_INVALID_YEAR'=>'Bitte ein gültiges 4-stelliges Jahr eingeben.',
'ERR_INVALID_DATE'=>'Bitte geben Sie ein gültiges Datum an.',
'ERR_INVALID_HOUR'=>'Bitte geben Sie eine gültige Stunde an.',
'ERR_INVALID_TIME'=>'Bitte geben Sie eine gültige Zeit ein.',
'NTC_CLICK_BACK'=>'Wählen Sie im Browser [Zurück] um den Fehler zu korrigieren.',
'LBL_LIST_ASSIGNED_USER'=>'zuständig',
'LBL_ASSIGNED_TO'=>'zuständig:',
'LBL_DATE_MODIFIED'=>'letzte Änderung:',
'LBL_DATE_ENTERED'=>'erstellt:',
'LBL_CURRENT_USER_FILTER'=>'nur meine:',
'NTC_LOGIN_MESSAGE'=>"Bitte anmelden.",
'LBL_NONE'=>'--keine--',
'LBL_BACK'=>'zurück',
'LBL_IMPORT'=>'importiere',
'LBL_EXPORT'=>'exportiere',
'LBL_EXPORT_ALL'=>'exportiere alle',
'LBL_QUICK_CREATE'=>'Schnellmenü',
'Export'=>'Export',
'Import'=>'Import',
'Merge'=>'Zusammenführen',
'ConvertLead'=>'Lead umwandeln',
'LBL_SHOW_RESULTS'=>'zeige Ergebnisse in',
'LBL_TOTAL_RECORDS_FOUND'=>'Gesamtanzahl gefunden :',
'LBL_SEARCH_RESULTS_FOR'=>' -- Suchergebnisse für ',
'LBL_TAG_SEARCH'=>' -- Tag-Suche für ',
'LBL_NO_DATA'=>'Keine Daten gefunden',
'NTC_MERGE_CONFIRMATION' => 'Sind Sie sicher?',
'LBL_MERGE_BUTTON_TITLE' => 'Zusammenführen',
'LBL_MERGE_BUTTON_KEY' => 'Zusammenführen',
'LBL_SELECTEMAILTEMPLATE_BUTTON_TITLE'=>'E-Mail Vorlage wählen',
'LBL_SELECTEMAILTEMPLATE_BUTTON_KEY'=>'E-Mail Vorlage wählen',
'LBL_SELECTEMAILTEMPLATE_BUTTON_LABEL'=>'E-Mail Vorlage wählen',
'LBL_MERGE_BUTTON_LABEL'=>'Zusammenführen',
'LBL_SENDMAIL_BUTTON_TITLE'=>'E-Mail senden',
'LBL_SENDMAIL_BUTTON_KEY'=> 'E-Mail senden',
'LBL_SENDMAIL_BUTTON_LABEL'=>'E-Mail senden',
'LBL_UPD_DESC'=>'Beschreibung',
'LBL_FILENAME'=>'Datei',
'LBL_FILE'=>'Datei',
'LBL_TYPE'=>'Typ',
'LBL_DOWNLOAD'=>'Download jetzt',
'LBL_OPERATION'=>'Operation',
'LBL_GROUP_ALLOCATION_TITLE'=>'Meine Gruppenzugehörigkeit ',
'LBL_ENTITY_NAME'=>'Name',
'LBL_GROUP_NAME'=>'Gruppe',
'LBL_ENTITY_TYPE'=>'Typ',
'LBL_NEW_TICKET'=>'Ticket neu',
'LBL_TITLE'=>'Titel',
'LBL_PRIORITY'=>'Priorität',
'LBL_STATUS'=>'Status',
'LBL_CHANGE_OWNER'=>'Besitzer wechseln',
'LBL_CHANGE_STATUS'=>'Status wechseln',
'LBL_MASS_DELETE'=>'Löschen',
'LBL_ADD_ITEM'=>'erstelle',
'LBL_ADD_NEW'=>'erstelle',
'LBL_DEDUCT'=>'Minus',
'LBL_CALENDAR_TITLE'=>'Kalender aufrufen...',
'LBL_CALENDAR_ALT'=>'Kalender aufrufen...',
'LBL_CALCULATOR_TITLE'=>'Rechner aufrufen...',
'LBL_CALCULATOR_ALT'=>'Rechner aufrufen...',
'LBL_CLOCK_TITLE'=>'Weltuhr zeigen...',
'LBL_CLOCK_ALT'=>'Weltuhr zeigen...',
'LBL_ALL_MENU_TITLE'=>'Alle Menüs öffnen...',
'LBL_ALL_MENU_ALT'=>'Alle Menüs öffnen...',
'LBL_CHAT_TITLE'=>'Chat...',
'LBL_CHAT_ALT'=>'Chat...',
'LBL_SEARCH_TITLE'=>'Suche in ',
'LBL_SEARCH_ALT'=>'Suche in ',
'LBL_SEARCH_STRING'=>'Suche...',
'LBL_SEARCH_FOR'=>'Suche nach',
'LBL_SEARCH_NOW_BUTTON'=>'Suche starten',
'LBL_GO_TO'=>'starte',
'LBL_FEWER_BUTTON'=>'Weniger',
'LBL_IN'=>'In',
'LBL_ADV_SEARCH_MSG_ANY'=>'Entspreche einer der folgenden Bedingungen',
'LBL_ADV_SEARCH_MSG_ALL'=>'Entspreche allen der folgenden Bedingungen',
'COMBO_ALL'=>'Alle',
'LBL_OPEN_ACTIVITIES'=>'Offene Aktivitäten',
'LBL_HISTORY'=>'Historie',
'LBL_ACTIVITY_HISTORY'=>'Aktivitätenhistorie',
'LBL_ATTACHMENTS'=>'Anhänge',
'LBL_ATTACHMENT'=>'Anhang',
'LBL_TIME'=>'Zeit',
'LBL_ACTION'=>'Aktion',
'LBL_SUBJECT'=>'Betreff',
'LBL_RELATED_TO'=>'bezogen auf',
'LBL_MULTIPLE'=>'Mehrere',
'LBL_DUE_DATE'=>'Ende',
'LBL_LAST_MODIFIED'=>'letzte Änderung',
'LBL_CREATED'=>'Erstellt',
'LBL_DESCRIPTION'=>'Beschreibung',
'LBL_NEW_TASK'=>'Neue Aufgabe',
'LBL_NEW_EVENT'=>'Neues Ereignis',
'LBL_ATTACHMENT_AND_NOTES'=>'Anhänge und Notizen',
'LBL_POTENTIAL_NAME'=>'Verkaufspotential',
'LBL_CONTACT_NAME'=>'Person',
'LBL_DEPARTMENT'=>'Abteilung',
'LBL_ROLE'=>'Rolle',
'LBL_EMAIL'=>'E-Mail',
'LBL_PHONE'=>'Telefon',
'LBL_PRODUCT'=>'Produkt',
'LBL_AMOUNT'=>'Betrag',
'LBL_CLOSE_DATE'=>'Abschluss',
'LBL_NEW_ATTACHMENT'=>'Neuer Anhang',
'LBL_PRODUCT_TITLE'=>'Produkte',
'LBL_NEW_PRODUCT'=>'Neues Produkt',
'LBL_PRODUCT_NAME'=>'Produkt',
'LBL_QUANTITY'=>'Menge',
'LBL_SALES_PRICE'=>'Verkaufspreis',
'LBL_PURCHASE_DATE'=>'Einkaufsdatum',
'LBL_TICKET_ID'=>'Ticket ID',
'LBL_TICKETS'=>'Tickets',
'LBL_POTENTIAL_TITLE'=>'Verkaufspotentiale',
'LBL_NEW_POTENTIAL'=>'Neues Verkaufspotential',
'LBL_LEAD_NAME'=>'Lead',
'LBL_ACCOUNT_NAME'=>'Organisation',
'LBL_ACCOUNT_TYPE'=>'Organisationstyp',
'LBL_USER_TITLE'=>'Benutzer',
'LBL_CONTACT_TITLE'=>'Personen',
'LBL_SHOWING' => 'zeige',
'LBL_SELECT_PRODUCT_BUTTON_LABEL'=>'Produkt wählen',
'LBL_VIEW'=>'zeige:',
'LBL_GROUP_VIEW'=>'Gruppe',
'LBL_SALES_STAGE'=>'Verkaufsstufe',
'LBL_PROBABILITY'=>'Wahrscheinlichkeit',
'LBL_BULK_MAILS'=>'Massenmailing',
'LBL_WORLD_CLOCK'=>'Weltuhr',
'LBL_CALCULATOR'=>'Rechner',
'LBL_CLOSE_WON' =>'gewonnen',			# 'Closed Won'
'LBL_CLOSE_LOST'=>'verloren',			# 'Closed Lost'
'LBL_USER'=>'Benutzer',
'LBL_TEAM'=>'Team',
'LBL_GROUP'=>'Gruppe',
'LBL_NONE_NO_LINE'=>'keine',
'LBL_SELECT_GROUP'=>'Wähle eine Gruppe',
'LBL_HOUR_AND_MINUTE'=>'(Stunden/Minuten)',
'YEAR_MONTH_DATE'=>'24:00',
'COMBO_LEADS'=>'Leads',
'COMBO_ACCOUNTS'=>'Organisationen',
'COMBO_CONTACTS'=>'Personen',
'COMBO_POTENTIALS'=>'Potentiale',
'COMBO_PRODUCTS'=>'Produkte',
'COMBO_HELPDESK'=>'Trouble Tickets',
'COMBO_USERS'=>'Benutzer',
'COMBO_CAMPAIGNS'=>'Kampagnen',
'LBL_SELECT'=>'wähle',
'LBL_EDIT'=>'Bearbeiten',
'LBL_DELETE'=>'Lö',
'Name'=>'Name',
'Company'=>'Organisation',
'Phone'=>'Telefon',
'Website'=>'Webseite',
'Email'=>'E-Mail',
'Assigned To'=>'zuständig',
'Account Name'=>'Organisation',
'City'=>'Ort',
'Title'=>'Titel',
'Potential'=>'Potential',
'Sales Stage'=>'Verkaufsstufe',
'Amount'=>'Betrag',
'Expected Close'=>'Abschluss',
'Subject'=>'Betreff',
'Contact Name'=>'Person',
'Related to'=>'bezogen auf',
'File'=>'Datei',
'Last Modified'=>'letzte Änderung',
'Close'=>'Schließen',
'Type'=>'Typ',
'Start Date/Due Date'=>'Datum',
'Date Sent'=>'Sendedatum',
'Ticket ID'=>'Ticket ID',
'Status'=>'Status',
'Priority'=>'Priorität',
'Product Name'=>'Produktname',
'Commission Rate'=>'Kommission',
'Quantity In Stock' => 'Lagermenge',
'Qty/Unit'=>'Einheit',
'Unit Price'=>'Preis',
'Question'=>'Frage',
'Category'=>'Kategorie',
'Price Book Name'=>'Preisliste',
'LBL_EVENT_ENDDATE'=>'Ende Datum & Zeit',
'LBL_CUSTOM_INFORMATION'=>'zusätzliche Information',
'LBL_NONE_SCHEDULED'=>'keine Termine',
'Leads'=>'Leads',
'Accounts'=>'Organisationen',
'Accounts & Contacts'=>'Organisationen & Personen',
'Contacts'=>'Personen',
'Potentials'=>'Verkaufspotentiale',
'Products'=>'Produkte',
'Emails'=>'E-Mails',
'HelpDesk'=>'Trouble Tickets',
'Activities'=>'Aktivitäten',
'Events'=>'Ereignisse',
'Tasks'=>'Aufgaben',
'Todo'=>'Aufgabe',
'Call'=>'Anruf',
'Meeting'=>'Meeting',
'PriceBook'=>'Preisliste',
'Calendar'=>'Kalender',
'Home'=>'Home',
'Campaigns'=>'Kampagnen',
'PriceBooks'=>'Preislisten',
'Faq' => 'Wissensbasis',
'Dashboards'=>'Cockpit',
'Reports'=>'Berichte',
'Vendors'=>'Lieferanten',
'Rss'=>'RSS',
'Portal'=>'Meine Seiten',
'Webmails'=>'Webmail',
'Attachments'=>'Anhänge',
'Ticket History'=>'Ticket-Historie',
'Purchase Order'=>'Einkaufsbestellung',
'Sales Stage History'=>'Verkaufshistorie',
'Users'=>'Benutzer',
'Admin'=>'Administrator',
'PurchaseOrder Status History'=>'Statushistorie für Einkaufsbestellungen',
'SalesOrder Status History'=>'Statushistorie für Verkaufsbestellungen',
'Quote Stage History'=>'Historie für Angebote',
'Invoice Status History'=>'Statushistorie für Rechnungen',
'LBL_TROUBLE_TICKET'=>'Trouble Ticket',
'My Home Page'=>'Startseite',
'Marketing'=>'Marketing',
'Sales'=>'Vertrieb',
'Support'=>'Support',
'Analytics'=>'Auswertung',
'Inventory'=>'Bestand',
'Tools'=>'Werkzeuge',
'Settings'=>'Einstellungen',
'LBL_INFORMATION'=>'Information',
'LBL_MORE'=>'mehr',
'LBL_BASIC'=>'Stammdaten',
'LBL_CREATING'=>'erstelle',
'LBL_DUPLICATING' => 'Klonen von',
'LBL_EDITING'=>'Bearbeiten',
'LBL_NEW'=>'Neu',
'Lead'=>'Lead',
'Account'=>'Organisation',
'Contact'=>'Person',
'Opportunity'=>'Potential',
'Product'=>'Produkt',
'Activity'=>'Aktivität',
'Event'=>'Ereignis',
'Task'=>'Aufgabe',
'Quote'=>'Angebot',
'Ticket'=>'Ticket',
'Campaign'=>'Kampagne',
'Dashboard'=>'Cockpit',
'Report'=>'Bericht',
'Vendor'=>'Lieferant',
'Webmail'=>'Webmail',
'LBL_NONE_INCLUDED'=>'keine Einträge vorhanden',
'LBL_ADD_TO'=>'hinzufügen zu',
'LBL_SELECT_TEMPLATE_TO_MAIL_MERGE'=>'Textvorlage wählen:',
'LBL_TITLE_OR_DESCRIPTION'=>'Titel / Beschreibung',
'LBL_RSS_FEEDS'=>'RSS Feeds',
'LBL_ADD_RSS_FEEDS'=>'Neuer RSS Feed',
'LNK_NEW_FAQ'=>'Neue Wissensbasis',
'Vendor Name'=>'Lieferant',
'LNK_WEARE'=>'Wir',
'LBL_ABOUTUS_TITLE'=>'vtiger CRM - Über uns',
'LBL_DISCUSS'=>'diskutiere mit anderen Benutzern',
'Quote Stage'=>'Angebotsstufe',
'Potential Name'=>'Verkaufspotential',
'Total'=>'Total',
'First Name'=>'Vorname',
'Last Name'=>'Nachname',
'User Name'=>'Benutzername',
'LBL_PORDER_BUTTON_TITLE'=>'Neuer Einkauf [Alt+O]',
'LBL_PORDER_BUTTON'=>'Neuer Einkauf',
'LBL_PORDER_BUTTON_KEY'=>'O',
'Tracking Number'=>'Bedarfsnummer',
'Order No'=>'Bestellnr.',
'Quote Name'=>'Angebotsname',
'Invoice No'=>'Rechnungsnr.',
'Quote No'=>'Angebotsnr.',
'Sales Order'=>'Kundenbestellung',
'COMBO_QUOTES'=>'Angebote',
'End Date'=>'Ende',
'End Date & Time' => 'Termin endet',
'Start Date'=>'Start',
'Start Date & Time' => 'Termin beginnt',
'Recurring Type'=> 'Wiederholungsart',
'SalesOrder'=> 'Verkäufe',
'LBL_QUOTE_NAME'=>'Angebotsname',
'LBL_NEW_QUOTE_BUTTON_TITLE'=>'Neues Angebot [Alt+Q]',
'LBL_NEW_QUOTE_BUTTON_KEY'=>'Q',
'LBL_NEW_QUOTE_BUTTON'=>'Neues Angebot',
'COMBO_PORDER'=>'Neuer Einkauf',
'COMBO_SORDER'=>'Neuer Verkauf',
'LBL_PORDER_NAME'=>'Einkauf',
'LBL_SORDER_NAME'=>'Verkauf',
'COMBO_INVOICES'=>'Rechnung',
'LBL_INVOICE_NAME'=>'Rechnung',
'LBL_QUOTES_NAME' => 'Angebot',
'LBL_HELPDESK_NAME'=>'Trouble Ticket',
'LBL_CAMPAIGN_NAME'=>'Kampagnenname',
'LBL_NEW_INVOICE_BUTTON_TITLE'=>'Neue Rechnung [Alt+I]',
'LBL_NEW_INVOICE_BUTTON_KEY'=>'I',
'LBL_NEW_INVOICE_BUTTON'=>'Neue Rechnung',
'LBL_NEW_SORDER_BUTTON_TITLE'=>'Neuer Verkauf [Alt+E]',
'LBL_NEW_SORDER_BUTTON_KEY'=>'E',
'LBL_NEW_SORDER_BUTTON'=>'Neuer Verkauf',
'LBL_PRODUCT_DETAILS'=>'Produktdetails',
'LBL_QTY_IN_STOCK'=>'Menge im Lager',
'LBL_QTY'=>'Menge',
'LBL_UNIT_PRICE'=>'Preis',
'LBL_LIST_PRICE'=>'Listenpreis',
'LBL_TOTAL'=>'Total',
'LBL_ADD_PRODUCT'=>'Produkt hinzufügen',
'LBL_SUB_TOTAL'=>'Zwischensumme',
'LBL_TAX'=>'Mwst.',
'LBL_ADJUSTMENT'=>'Anpassung',
'LBL_GRAND_TOTAL'=>'Summe',
'LBL_QUOTE_ID'=>'Angebots-ID',
'LBL_SALES_ORDER_ID'=>'Verkaufsnummer',
'LBL_PURCHASE_ORDER_ID'=>'Einkaufsnummer',
'LBL_EXPORT_TO_PDF'=>'Export als PDF',
'LBL_HOME_KEY_METRICS'=>'benutzerdefinierte Listen',
'LBL_HOME_METRICS'=>'Listenname',
'LBL_HOME_COUNT'=>'Anzahl',
'LBL_JSCALENDAR_LANG'=>'de',
'LNK_CV_EDIT'=>'Bearbeiten',
'LNK_CV_DELETE'=>'Löschen',
'LNK_CV_CREATEVIEW'=>'Ansicht erstellen',
'LBL_UPD_FIELD_ORD'=>'Update Feldanordnung',
'LBL_SEND_CUSTOM_MAIL_BUTTON'=>'Sende E-Mail',
'LBL_UPDATED_TODAY'=>'Updated heute',
'LBL_UPDATED'=>'Updated',
'LBL_DAY_AGO'=>'Tage zurück',
'LBL_DAYS_AGO'=>'Tage zurück',
'Jan'=>'Jan',
'Feb'=>'Feb',
'Mar'=>'Mär',
'Apr'=>'Apr',
'May'=>'Mai',
'Jun'=>'Jun',
'Jul'=>'Jul',
'Aug'=>'Aug',
'Sep'=>'Sep',
'Oct'=>'Okt',
'Nov'=>'Nov',
'Dec'=>'Dez',
'Campaign Name'=>'Kampagnenname',
'Campaign Type'=>'Kampagnentyp',
'Campaign Status'=>'Kampagnenstatus',
'Expected Revenue'=>'Erwarteter Umsatz',
'Expected Close Date'=>'Abschluss',
'LBL_ACTIONS'=>'Aktionen',
'LBL_SEND'=>'Senden',
'LBL_VAT'=>'Mwst. 1',
'LBL_SALES'=>'Vertrieb',
'LBL_SERVICE'=>'Dienstleistung',
'LBL_TAX_DETAILS'=>'Steuerdetails',
'LBL_TAX_CALCULATION'=>'Steuerberechnung',
'LBL_TAX_NAME' => 'Steuerbezeichung',
'LBL_TAX_VALUE' => 'Prozentwert',
'COVERED_PERCENTAGE'=>'(%)',
'LBL_TAG_CLOUD'=>'Tag Wolke',
'LBL_FOR'=>'für',
'LBL_PO_STATUS'=>'Status der Einkaufsbestellung',
'LBL_SO_STATUS'=>'Status der Verkaufsbestellung',
'LBL_INVOICE_STATUS'=>'Rechnungsstatus',
'LBL_MODULE'=>'Modul',
'Active'=>'Aktiv',
'Inactive'=>'Inaktiv',
'Today'=>'Heute',
'Last 2 Days'=>'Letzte 2 Tage',
'Last Week'=>'Letzte Woche',
'This Week'=>'Diese Woche',
'This Month'=>'Dieser Monat',
'This Year'=>'Dieses Jahr',
'LBL_PLEASE_CLICK'=>'Klicken Sie',
'LBL_TO_CONFIGURE'=>'zur Konfiguration',
'LBL_HERE'=>'hier',
'LBL_RECORDS'=>'Datensätze',
'LBL_SCROLL'=>'[Nach oben]',
'LBL_EXPAND_COLLAPSE'=>'mehr/weniger',
'LBL_RCPY_ADDRESS'=>'Kopiere Lieferadresse',
'LBL_LCPY_ADDRESS'=>'Kopiere Rechnungsadresse',
'LBL_RECORD_ID'=>'Datensatz ID',
'LBL_ACTION_DATE'=>'Ausführungsdatum',
'LBL_HOMEPAGE_DASHBOARD'=>'Startseite Cockpit',
'LBL_NO'=>'Keine',
'LBL_FOUND'=>'Die Liste ist leer',
'LBL_YOU_CAN_CREATE'=>'Sie können einen neuen Eintrag jetzt anlegen. ',
'LBL_NOW'=>'jetzt erstellen',
'LBL_CLICK_THE_LINK'=>'Auf den Link klicken',
'LBL_CREATE'=>' erstelle',
'LBL_A'=>'eine',
'LBL_AN'=>'eine',
'LBL_YOU_ARE_NOT_ALLOWED_TO_CREATE'=>'Sie haben dafür keine Berechtigung.',
'LBL_TRANSFER_OWNERSHIP'=>'Übertrage Besitzrechte an',
'LBL_SELECT_STATUS'=>'Neuen Status wählen',
'LBL_UPDATE_OWNER'=>'Update Besitzer',
'LBL_UPDATE_STATUS'=>'Update Status',
'LBL_NET_PRICE'=>'Preis',
'LBL_TOOLS'=>'Werkzeuge',
'LBL_DISCOUNT'=>'Rabatt',
'LBL_TOTAL_AFTER_DISCOUNT'=>'Total nach Rabatt',
'LBL_NET_TOTAL'=>'Summe',
'LBL_SHIPPING_AND_HANDLING_CHARGES'=>'Versandkosten',
'LBL_TAX_FOR_SHIPPING_AND_HANDLING'=>'Versandkosten Mwst.',
'LBL_FINISH'=>'Fertigstellen',
'LBL_IMAGE_DELETED'=>'Bild gelöscht',
'LBL_TAX_MODE'=>'Mwst',
'LBL_CLEAR_COMMENT'=>'Kommentar löschen',
'LBL_ZERO_DISCOUNT'=>'Kein Rabatt',
'LBL_OF_PRICE'=>'des Preises',
'LBL_DIRECT_PRICE_REDUCTION'=>'Direkt Preisreduktion',
'LBL_INDIVIDUAL'=>'Individuell',
'LBL_CPY_MAILING_ADDRESS'=>'Kopiere Postadresse',
'LBL_CPY_OTHER_ADDRESS'=>'Kopiere weitere Adresse',
'LBL_PERMISSION'=>'Vorgang wurde vom CRM Administrator gesperrt!',
'VTIGER'=>'vtiger',
'LBL_DIRECT_AMOUNT_DISCOUNT'=>'direkter Rabatt',
'LBL_NO_DISCOUNT_FOR_THIS_PRODUCT'=>'kein Rabatt für dieses Produkt',
'LBL_NO_DISCOUNT_FOR_THIS_LINE_ITEM'=>'kein Rabatt',
'LBL_TOTAL_TAX_AMOUNT'=>'Total Mwst.',
'LBL_FINAL_DISCOUNT_AMOUNT'=>'Abschlussrabatt',
'LBL_SHIPPING_AND_HANDLING_CHARGE'=>'Versandkosten',
'LBL_GO_BACK'=>'Zurück',
'LBL_RECORD_DELETE'=>'Die Daten, die Sie versuchen anzusehen, wurden bereits gelöscht.',
'Part Number'=>'Produktcode',
'Salutation'=>'Anrede ',
'Rating'=>'Bewertung',
'industry'=>'Branche',
'Severity'=>'Gewichtung',
'Product Category'=>'Produktkategorie',
'GL Account'=>'FiBu Konto',
'Usage Unit'=>'Mengeneinheit',
'Carrier'=>'Carrier',
'Expected Response'=>'Erwarteter Rücklauf',
'LBL_ADDRESS_INF'=>'Adressinformation',
'yes'=>'ja',
'no' => 'nein',
'on'=>'ja',
'off'=>'nein',
'LBL_RENAMEPROFILE_BUTTON_LABEL'=>'Umbenennen',
'LBL_RENAME_PROFILE'=>'Profil umbenennen',
'LBL_PROFILE_NAME'=>'Profilname',
'LBL_START_DATE'=>'Startdatum',
'LBL_START_DATE_TIME'=>'Termin beginnt',
'LBL_END_DATE'=>'Endedatum',
'LBL_END_DATE_TIME'=>'Termin endet',
'LBL_CREATE_MERGE_TEMPLATE'=>'Textvorlage erstellen ',
'LBL_IMG_FORMATS'=>'(Nur jpg, gif, bmp und png Bilder)',

//Added for Taxmode in detail view of Product Details.
'group'=>'Gruppe',
'individual'=>'Individuell',

//Added for values of picklist in Advanced Search filter
//Modified for 5.0.3 GA release
'contains'=>'beinhaltet',
'does_not_contains'=>'beinhaltet nicht',
'is'=>'ist',
'is_not'=>'ist nicht',
'begins_with'=>'beginnt mit',
'ends_with'=>'endet mit',
'greater_than'=>'größer als',
'less_than'=>'weniger als',
'greater_or_equal'=>'größer oder gleich',
'less_or_equal'=>'weniger oder gleich',

//For Product Details
'LABEL_SET_DISCOUNT_FOR_COLON'=>'setze Rabatt für :',
'LABEL_SET_TAX_FOR'=>'setze Steuer für',
'LABEL_SET_DISCOUNT_FOR'=>'setze Rabatt für',
'LABEL_SET_GROUP_TAX_FOR_COLON'=>'setze Gruppensteuer für :',
'LABEL_SET_DISCOUNT_FOR_X_COLON'=>'setze Rabatt für x :',
'LABEL_SET_TAX_FOR_X'=>'setze Steuer für x',
'LABEL_SET_SH_TAX_FOR_COLON'=>'setze S&H Steuer für :',

'NO_DATA_AVAILABLE_WITH_SPECIFIED_PERIOD'=>'Innerhalb des angegebenen Zeitrahmens gibt es keine Daten.',

//Added for 5.0.3
'Files_Maximum_6'=>'Dateimaximum 6',
'To'=>'An:',

'Date & Time' => 'Datum & Zeit',
'Reminder' => '[Erinnerung:',
'Visit_Link' => 'Bitte klicken Sie auf den Link für mehr Informationen.',
'Click here' => 'Klick hier',
'Subject' => 'Titel',
'Support_starting' => 'Support beginnt',
'Congratulations' => 'Glückwunsch! Ihr Support beginnt heute',
'Hello_Support' => 'Hallo! Unser Support beginnt für',
'Support_Ending_Subject' => 'Betreff: Unser Support endet',
'Support_Ending_Content' => 'Sehr geehrter CRM Nutzer,<br><br> Hiermit wollen wir Sie über das Datum des Supportes für Ihre Ware von uns informieren <b>',
'kindly_renew' => '</b>endet in Kürze. Bitte setzen Sie sich mit unseren Vertrieb in Verbindung<br>Mit freundlichen Grüßen,<br>Ihr Support Team<br>',
'Dear_Admin' => 'Hallo CRM Administrator,<br> Dies ist eine automatische Benachrichtigung aus Ihrem CRM System. Im CRM sind zu viele offene Tickets hinterlegt. Bitte kümmern Sie sich darum.<br><br> Danke!<br> Ihr CRM System<br>',
'Pending_Tickets' => 'Zu viele offene Tickets',
'Pending_Ticket_notification' => 'Benachrichtigung über offene Tickets',
'Kind_Attention' => 'Hallo CRM Administrator,<br> Dies ist eine automatische Benachrichtigung aus Ihrem CRM System. Das Ticket mit der Nummer ',
'Thank_You_HelpDesk' => ' sollte geschlossen werden<br> Danke,<br> Ihr CRM System<br>',
'Big_Deal_Closed_Successfully' => 'Großes Geschäft erfolgreich abgeschlossen',
'Dear_Team' => 'Hallo Team,<br>',
'Potential_Name' => 'Potentialname:',
'Potential_Id' => 'Potentialnr.:',
'Dear_Team_Time_to_Party' => 'Hallo Team,<br>Glückwunsch an alle Beteiligten! <br>Wir haben ein Geschäft mit mehr als 10.000 EUR abgeschlossen<br> Sehr schön!<br>',
'Task_Not_completed' => 'Aufgabe nicht abgeschlossen',
'Too_many_pending_tickets' => 'Zu viele offene Tickets',
'Dear_Admin_too_ many_tickets_pending' => 'Hallo CRM Administrator,<br> Dies ist eine automatische Benachrichtigung aus Ihrem CRM System. Im CRM sind zu viele Tickets offen. Bitte kümmern Sie sich darum<br><br> Danke,<br> Ihr CRM System<br>',

//Added for java script alerts
'DELETE_CONFIRMATION' => 'Sind Sie sicher? ',
'SELECT_ATLEAST_ONE' => 'Btte wenigstens einen Eintrag auswählen.',
'DELETING_ACCOUNT' => 'Wenn Sie diese Organisation löschen, werden auch die darauf bezogenen Potentiale, Angebote, Verkaufsbestellungen und Rechnungen entfernt. Sind Sie sicher, dass Sie das wirklich tun möchten? ',
'DELETING_VENDOR' => 'Wenn Sie diesen Lieferanten löschen, werden auch die darauf bezogenen Einkaufsbestellungen entfernt. Sind Sie sicher, dass Sie das wirklich tun möchten?',
'PLEASE_SELECT_MAILID' => 'Bitte geben Sie eine E-Mail Adresse an.',
'OVERWRITE_EXISTING_ACCOUNT1' => 'Wollen Sie die existierende Adresse durch die ausgewählte Adresse (',
'OVERWRITE_EXISTING_ACCOUNT2' => ') ersetzen?',
'MISSING_FIELDS' => 'folgende Pflichtangaben fehlen:',
'NOT_ALLOWED_TO_EDIT' => 'Sie haben keine Berechtigung dieses Feld zu bearbeiten.',
'COLUMNS_CANNOT_BE_EMPTY' => 'Die ausgewählten Spalten dürfen nicht leer sein.',
'CANNOT_BE_EMPTY' => ' darf nicht leer sein.',
'CANNOT_BE_NONE' => ' darf nicht leer sein.',
'SERVERNAME_CANNOT_BE_EMPTY' => 'Bitte einen Servernamen angeben.',
'ENTER_VALID' => 'Bitte geben Sie einen gültigen Wert ein für ',
'SHOULDBE_LESS' => ' sollte kleiner sein als ',
'SHOULDBE_LESS_EQUAL' => ' sollte kleiner oder gleich sein zu ',
'SHOULDBE_EQUAL' => ' sollte gleich sein zu ',
'SHOULDBE_GREATER' => ' sollte grösset sein als ',
'SHOULDBE_GREATER_EQUAL' => ' sollte grösser oder gleich sein zu ',
'INVALID' => 'Ungültig ',
'EXCEEDS_MAX' => ' überschreitet den zulässigen Maximalwert ',
'OUT_OF_RANGE' => ' liegt ausserhalb des zulässigen Bereichs',
'SHOULDNOTBE_EQUAL' => ' sollte noch gleich sein zu ',
'PORTAL_PROVIDE_EMAILID' => 'Portalnutzer brauchen eine E-Mail Adresse',
'ADD_CONFIRMATION' => 'Sind Sie sicher?',
'ACCOUNTNAME_CANNOT_EMPTY' => 'Ein Organisationsname muss angegeben werden.',
'CANT_SELECT_CONTACTS' => "Sie dürfen keine Personenbezüge zu Leads eingeben.",
'LBL_THIS' => 'Der Eintrag ',
'DOESNOT_HAVE_MAILIDS' => " hat keine E-Mail Adresse",
'DOESNOT_HAVE_AN_MAILID' => '" '."hat keine E-Mail Adresse",
'ARE_YOU_SURE' => 'Sind Sie sicher?',
'MISSING_REPORT_NAME' => 'Der Name des Berichtes fehlt.',
'REPORT_NAME_EXISTS' => 'Diesen Berichtsnamen gibt es bereits.',
'WANT_TO_CHANGE_CONTACT_ADDR' => 'Wollen Sie die Adressen von den Personen, die sich auf diese Organisation beziehen, ändern?',
'SURE_TO_DELETE' => 'SInd Sie sicher?',
'RECORDS' => ' Datensätze ?',
'NO_PRODUCT_SELECTED' => 'Sie müssen wenigstens ein Produkt auswählen.',
'VALID_FINAL_PERCENT' => 'Bitte geben Sie einen Rabatt in Prozent richtig an.',
'VALID_FINAL_AMOUNT' => 'Bitte geben Sie den Betrag für den Rabatt richtig an.',
'VALID_SHIPPING_CHARGE' => 'Bitte geben Sie die Versandkosten richtig ein.',
'VALID_ADJUSTMENT' => 'Bitte geben Sie die Anpassung richtig ein.',
'SELECTED_MORE_THAN_ONCE' => 'Die folgenden Produkte wurde mehr als einmal ausgewählt.',
'WANT_TO_CONTINUE' => 'Weiter?',
'ENTER_VALID_TAX' => 'Bitte geben Sie einen gültigen Wert für die Mwst. ein.',
'VALID_TAX_NAME' => 'Bitte geben Sie einen gültigen Steuernamen ein.',
'CORRECT_TAX_VALUE' => 'Bitte geben Sie den Wert für die Steuer richtig ein.',
'ENTER_POSITIVE_VALUE' => 'Nur positve Werte sind zulässig.',
'LABEL_SHOULDNOT_EMPTY' => 'Sie müssen der Steuer einen Namen geben.',
'NOT_VALID_ENTRY' => 'ist keine gültige Angabe. Bitte geben Sie einen korrekten Wert ein.',
'VALID_DISCOUNT_PERCENT' => 'Bitte geben Sie einen Rabatt in Prozent richtig an.',
'VALID_DISCOUNT_AMOUNT' => 'Bitte geben Sie den Betrag für den Rabatt richtig an.',
'SELECT_TEMPLATE_TO_MERGE' => 'Bitte eine Textvorlage auswählen.',
'MISSING_REQUIRED_FIELDS' => 'Die folgenden Pflichfelder fehlen: ',
'READONLY' => "nur Lesen zulässig",
'SELECT_ATLEAST_ONE_USER' => 'Bitte wenigstens einen Nutzer auswählen.',
'DISABLE_SHARING_CONFIRMATION' => 'Sind Sie sicher, dass Sie die Nutzerrechte einschränken wollen?',
'USERS' => ' Benutzer ?',
'ENDTIME_GREATER_THAN_STARTTIME' => 'Die Zeitangabe zum Ende muss später als die Anfangszeit sein.',
'FOLLOWUPTIME_GREATER_THAN_STARTTIME' => 'Der Zeitpunkt des Nachfassens sollte nach der Anfangszeit liegen. ',
'MISSING_EVENT_NAME' => 'Dem Ereignis wurde kein Name gegeben.',
'EVENT_TYPE_NOT_SELECTED' => 'Der Typ des Ereignisses wurde nicht ausgewählt.',
'OPPORTUNITYNAME_CANNOT_BE_EMPTY' => 'Sie müssen dem Potential einen Namen angeben.',
'CLOSEDATE_CANNOT_BE_EMPTY' => 'Sie müssen ein Abschlussdatum angeben.',
'SITEURL_CANNOT_BE_EMPTY' => 'Sie müssen eine URL angeben.',
'SITENAME_CANNOT_BE_EMPTY' => 'Sie müssen der Seite einen kurzen und prägnanten Namen geben.',
'LISTPRICE_CANNOT_BE_EMPTY' => 'Der Listenpreis muss angegeben werden.',
'INVALID_LIST_PRICE' => 'Die Angabe zum Listenprei ist fehlerhaft.',
'PROBLEM_ACCESSSING_URL' => 'Es gibt ein Problem mit der URL: ',
'CODE' => ' Code: ',
'WISH_TO_QUALIFY_MAIL_AS_CONTACT' => 'Wollen Sie diese Mail als Person qualifizieren?',
'SELECT_ATLEAST_ONEMSG_TO_DEL' => 'Bitte wenigstens eine Nachricht auswählen.',
'ERROR' => 'Fehler',
'FIELD_TYPE_NOT_SELECTED' => 'Feldtype wurde nicht ausgewählt',
'SPECIAL_CHARACTERS_NOT_ALLOWED' => 'Sonderzeichen sind im Feldnamen nicht zulässig',
'DUPLICATE_MAPPING_ACCOUNTS' => 'Doppelter Bezug für Organisationen!',
'DUPLICATE_MAPPING_CONTACTS' => 'Doppelter Bezug für Personen!',
'DUPLICATE_MAPPING_POTENTIAL' => 'Doppelter Bezug für Potentiale!',
'ERROR_WHILE_EDITING' => 'Fehler beim Bearbeiten',
'PLEASE_ENTER_TAG' => 'Bitte einen Tag angeben',
'PLEASE_SELECT_LINE_ITEM' => 'Bitte ein Eintrag auswählen',
'DUPLICATE_ENTRIES_FOUND' => "Doppelter Eintrag gefunden \'",
'ROLE_SHOULDHAVE_INFO' => 'Eine Rolle muss mindestens ein Profil haben.',
'ENTER_VALID_CONVERSION_RATE' => 'Bitte einen gültigen Umrechnungswert angeben',
'GROUPNAME_CANNNOT_BE_NONE' => 'Der Gruppenname muss angegeben werden',
'GROUP_SHOULDHAVE_ONEMEMBER_INFO' => 'Eine Gruppe muss mindestens ein Mitglied haben.',
'MAP_DELETED_INFO' => 'Dieser Bezug wurde gelöscht.',
'MUSTHAVE_ONE_REQUIREDFIELD' => 'Ein Pflichtfeld muss angegeben werden \n',
'COLUMNS_CANNOT_BE_DUPLICATED' => 'Spalten dürfen nicht doppelt ausgewählt werden.',
'SPECIFY_ROLE_INFO' => 'Bitte wählen Sie eine Rolle aus, auf dem die Rolle des Nutzers übertragen werden soll.',
'FOLDERNAME_CANNOT_BE_EMPTY' => 'Sie müssen einen Verzeichnisnamen angeben.',
'FOLDER_NAME_ALREADY_EXISTS' => 'Ein Verzeichnis mit diesem Namen gibt es bereits.',
'SELECT_ATLEAST_ONE_REPORT' => 'Bitte wenigstens einen Bericht auswählen.',
'DELETE_FOLDER_CONFIRMATION' => "Sind Sie sicher, dass Sie dieses Verzeichnis entfernen wollen  \'",
'DELETE_REPORT_CONFIRMATION' => 'Sind Sie sicher, dass Sie diesen Bericht entfernen wollen?',
'MOVE_REPORT_CONFIRMATION' => 'Sind Sie sicher, dass Sie diesen Bericht verschieben wollen zum ',
'FOLDER' => ' Verzeichnis?',
'ACCOUNT_ACCESS_INFO' => 'Der Zugang auf Potentiale, HelpDesk, Angebote, Verkaufsbestellungen und Rechnungen muss auf privat gesetzt werden, wenn der Zugang zu Organisationen auf privat gesetzt wurde.',
'PROFILENAME_CANNOT_BE_EMPTY' => 'Ein Profil muss einen Namen haben.',
'PROFILE_DETAILS_UPDATED' => 'Die Profildetails wurden aktualisiert.',
'CURRENCY_CHANGE_INFO' => 'Die Änderungen zur Währung wurden übernommen.',
'CURRENCY_CONVERSION_INFO' => 'Nutzen Sie Dollar $ als Währung? \n Klicken OK um bei $ zu bleiben  und Abbrechen um die Währungsumrechnung festzulegen.',
'THE_EMAILID' => "Die E-Mail Adresse \'",
'EMAIL_FIELD_INVALID' => "\' in dem E-Mail Feld ist ungültig",
'SELECT_VALID_IMAGE' => 'Bitte wählen Sie ein Bild im richtigen Format aus.',
'EMAIL_FILED_IS' => "\' im E-Mail Feld ist ",
'OTHER_EMAIL_FILED_IS' => "\' im andern E-Mail Feld ist ",
'YAHOO_EMAIL_FILED_IS' => "\' im Yahoo E-Mail Feld ist ",
'INVALID_ADD_IN_EMAILFIELD' => '\" keine gültige E-Mail Adresse',
'INVALID_ADD_IN_OTHER_EMAILFIELD' => '\" keine gültige E-Mail Adresse',
'ENTER_VALID_4DIGIT_YEAR' => 'Die Jahresangabe ist vierstellig zwischen ',
'AND' => '  und ',
'DATABASE_CHANGE_CONFIRMATION' => 'Sind Sie sicher, das Datenbankänderungen übernommen werden sollen von ',
'TO' => ' bis zu ',
'DELETE_RSSFEED_CONFIRMATION' => 'Wollen Sie den RSS Feed wirklich löschen?',
'NOT_PERMITTED_TO_EXPORT' => 'Sie haben keine Berechtigung für einen Export!',

//Added for 5.0.3
'MSG_DEAR'=>'Sehr geehrte(r) Herr/Frau',
'MSG_REGARDING'=>'In Ihrem CRM System wurde ein Eintrag zum Modul',
'MSG_UPDATION'=>'aktualisiert - siehe',
'MSG_THE'=>'Ein Eintrag im CRM System vom Typ ',
'MSG_HAS_BEEN_UPDATED'=>'wurde verändert',
'MSG_ASSIGNMENT'=>'Ihnen zugewiesen - siehe',
'MSG_HAS_BEEN_ASSIGNED_TO_YOU'=>'wurde Ihnen übergeben',
'MSG_DETAILS_ARE'=>'Hier sind die Details',
'MSG_ID'=>'Nr.: ',
'MSG_THANK_YOU'=>'Danke für Ihre Aufmerksamkeit',
'MSG_HAS_BEEN_CREATED_FOR'=>'wurde erstellt für',
'MSG_THANKS'=>'Danke,',
'MSG_VTIGERTEAM'=>' vTiger Team',
'MSG_IS_NOT_UPLOADED'=>'wurde nicht geladen. Zulässige Dateitypen - jpeg, png, jpg, pjpeg, x-png oder gif',
'MSG_IMAGE_ERROR'=>'Das Bild wurde nicht gefunden.',

'Information'=>'Information',
'Address'=>'Adresse',
'Custom Information'=>'Information',
'Portal Information'=>'- Portalinformation',
'Description'=>'Beschreibung',
'Expectations'=>'Erwartungen',
'Pricing Information'=>'Preisinformation',
'Stock Information'=>'Lagerinformation',
'Solution'=>'Lösung',
'Terms and Conditions'=>'AGB',
'LBL_SEARCHING'=>'Suche... bitte warten',
'LBL_SKYPE'=>'Skype',
'LBL_FIND'=>'Los',
'LBL_CLEAR'=>'Löschen',
// Added for display the label of Invoice no
'invoice no'=>'Rechnungsnr.',
//Added for title to the button Select Lead
'LBL_SELECT_LEAD_BUTTON_LABEL' => 'Lead auswählen',
//Added for the link Read License in footer
'LNK_READ_LICENSE'=>'Lizenzbestimmungen',
'ACTIVITIES' => 'Aktivitäten',
'MAP_NAME_EXISTS'=>'Dieser Name . \n Do you want to overwrite it?',
'FOLDER_NAME_ALLOW_20CHARS'=> 'Die Länge des Namens ist auf 20 Zeichen begrenzt.',
'SPECIAL_CHARS_NOT_ALLOWED' => 'Sonderzeichen sind hier nicht zulässig.',
//Added for title for SignIn Image.
'LBL_SIGN_IN'=>'Login',

//Added for title of Root Image
'LBL_ROOT'=>'Root',
'LBL_FIRST'=>'Anfang',
'LBL_LAST'=>'Ende',

'LBL_CONTACT_LAST_NAME'=>'Person - Familienname',
'LBL_CONTACT_FIRST_NAME'=>'Person - Vorname',
'Office Phone'=>'Tel. direkt',
'Sender'=>'Sender',
'Website'=>'Webseite',
'Activity Type'=>'Aktivitätentyp',
'Due Date'=>'zu erledigen bis',
'Created Time'=>'erstellt',
'Modified Time'=>'geändert',
'FAQ Id'=>'Wissensbasisnr.',
'Lead Status'=>'Leadstatus',
'Lead Source'=>'Leadquelle',
'Quote No'=>'Angebotsnr.',
'Yahoo Id'=>'Yahoo E-Mail',

// Added/Updated for vtiger CRM 5.0.4
'LBL_CHARSET' => 'UTF-8',
'Lost Lead' => 'verlorener Lead',
'LBL_SEND_EMAIL_PDF' => 'Sende E-Mail mit PDF',
//Added for incoming mail server settings form js validation
'ERR_INVALID_PAGE_COUNT' => "Seitenzahl ungültig",
//'Product Code' => 'Part Number',
'Quotes' => 'Angebote',
'PurchaseOrder' => 'Einkaufsbestellung',
'SalesOrder' => 'Verkaufsbestellung',
'Invoice' => 'Rechnung',
//added for #3012
'LBL_CREATING_NEW_Contact' => 'Neue Person erstellen',
'LBL_CREATING_NEW_Campaign' => 'Neue Kampagne erstellen',
'LBL_CREATING_NEW_Lead' => 'Neuen Lead erstellen',
'LBL_CREATING_NEW_Account' => 'Neue Organisation erstellen',
'LBL_CREATING_NEW_Potential' => 'Neues Potential erstellen',
'LBL_CREATING_NEW_Quotes' => 'Neues Angebot erstellen',
'LBL_CREATING_NEW_SalesOrder' => 'Neue Verkaufsbestellung erstellen',
'LBL_CREATING_NEW_Invoice' => 'Neue Rechnung erstellen',
'LBL_CREATING_NEW_Products' => 'Neues Produkt erstellen',
'LBL_CREATING_NEW_PriceBooks' => 'Neue Preisliste erstellen',
'LBL_CREATING_NEW_HelpDesk' => 'Neues Ticket erstellen',
'LBL_CREATING_NEW_Faq' => 'Neue Wissensbasis erstellen',
'LBL_CREATING_NEW_Vendors' => 'Neuen Lieferanten erstellen',
'LBL_CREATING_NEW_PurchaseOrder' => 'Neue Einkaufsbestellung erstellen',
'LBL_SEND_EMAIL_PDF' => 'Sende E-Mail mit PDF',
'LBL_UPDATE' => 'Update',
//Added for incoming mail server settings form js validation
'ERR_INVALID_PAGE_COUNT' => "Seitenzahl ungültig",
'LBL_CAL_LIMIT_MSG'=>'Es werden nur Jahresangaben in dem Bereich von 1970 bis 2037 unterstützt.',

//added for fix i18n issue #4038 when importing contacts
'Mobile' => 'Handy',
'Home Phone' => 'privates Tel.',
'Other Phone' => 'anderes Tel.',
'Fax' => 'Fax',
'Department' => 'Abteilung',
'Birthdate' => 'Geburtsdatum',
'Reports To' => 'berichtet an',
'Assistant' => 'Assistent',
'Assistant Phone' => 'Assistent Tel.',
'Do Not Call' => 'nicht anrufen',
'Email Opt Out' => 'E-Mail Opt. aus',
'Reference' => 'Referenz',
'Notify Owner' => 'Besitzer benachrichtigen',
'Portal User' => 'Portalnutzer',
'Support Start Date' => 'Support Anfangsdatum',
'Support End Date' => 'Support Endedatum',
'Mailing Street'=>'Straße',
'Other Street'=>'weitere Straße',
'Mailing City'=>'Ort',
'Other City'=>'weiterer Ort',
'Mailing State'=>'Bundesland',
'Other State'=>'weiteres Bundesland',
'Mailing Zip'=>'PLZ',
'Other Zip'=>'weitere PLZ',
'Mailing Country'=>'Land',
'Other Country'=>'weiteres Land',
'Mailing Po Box'=>'Postfachnr.',
'Other Po Box'=>'weitere Postfachnr.',
'Contact Image' => 'Bild der Person',

//Export Records STARTS--->
'LBL_EXPORT_TYPE_1'=>'Export Typ 1:',
'LBL_EXPORT_TYPE_2'=>'Export Typ 2:',
'LBL_SEARCH_CRITERIA_RECORDS'=>'exportiere Aufzeichnungen entsprechend den Suchkriterien',
'LBL_EXPORT_RECORDS'=>'exportiere alle Aufzeichnungen',
'LBL_WITH_SEARCH'=>'exportiere mit Filter',
'LBL_WITHOUT_SEARCH'=>'exportiere ohne Filter',
'LBL_ALL_DATA'=>'exportiere alle Daten',
'LBL_DATA_IN_CURRENT_PAGE'=>'exportiere Daten dieser Seite',
'LBL_ONLY_SELECTED_RECORDS'=>'exportiere ausgewählte Daten',
'LBL_YES'=>'Ja',
'LBL_NO'=>'Nein',
'Planned'=>'geplant',
'Held'=>'durchgeführt',
'Not Held'=>'nicht durchgeführt',
'Call'=>'Anruf',
'Meeting'=>'Meeting',
'Task'=>'Aufgabe',
'Completed'=>'erledigt',
'Deferred'=>'verschoben',
'Not Started'=>'Nicht begonnen',
'In Progress'=>'In Bearbeitung',
'Pending Input'=>'erwarte Zuarbeit',
//Export Records <-----ENDS

'Trouble Tickets'=>'Trouble Tickets',
'LBL_NOT_ACCESSIBLE'=>'Ansicht gesperrt',

//Added for Existing Picklist Strings for both Lead module (convert div) and for potential module.

'Prospecting'=>'Vorschau',
'Qualification'=>'Qualifikation',
'Needs Analysis'=>'Bedarfsanalyse',
'Value Proposition'=>'Wertanalyse',
'Id. Decision Makers'=>'Entscheider identifizieren',
'Perception Analysis'=>'Bewertung',
'Proposal/Price Quote'=>'Angebot',
'Negotiation/Review'=>'Verhandlung',
'Closed Won'=>'geschlossen gewonnen',
'Closed Lost'=>'geschlossen verloren',
'NOTE'=>'Notiz',
//Added for Migration Alert
'before_migration'=>'vor Beginn der Migration',
'Set_the_value_of'=>'setzen Sie den Wert von',
'as'=>'als',
'ie'=>'z.B.,',
'add_at_end_of_file'=>'Bitte ergänzen Sie die config.inc.php am Ende mit den folgenden Zeilen',
// Added for Error message on Send Email failure
'LBL_MAIL_SEND_STATUS' => 'Mail Send Status:',
'LBL_MAIL_NOT_SENT_TO_USER' => 'Es konnte keine Mail gesendet werden. Nutzer: ',
'LBL_PLS_CHECK_EMAIL_N_SERVER' => 'Bitte die E-Mail Adresse und die Servereinstellungen überprüfen.',
'PLEASE_FILL_QUANTITY' => 'Bitte die Menge angeben',
'LBL_SOLUTION'=>'Lösung',
'LBL_COMMENTS'=>'Kommentare',
'RELATED'=>'bezogen',
'SHOW_ALL'=>'Zeige alle',
'RELATED_PARENT'=>'bezogen auf übergeordnetes Modul',
//Added for select parent role button in picklist
'LBL_SELECT_PARENTROLE' => 'Die übergeordnete Rolle selektieren',
//Added for migration check
'LBL_MIGRATION_CHECK'=>'Versionen in der Datenbank und der Datei sind gleich. Es kann keine Migration gemacht werden.',
//Added for ticket #4595
'LBL_RECORD_NOT_FOUND'=>'Der Eintrag wurde nicht gefunden',
//Added for i18n issue (report 06/12/2007)
'Reorder Level' => 'Reorder Level',
'Handler' => 'Verantwortlich',
'Qty In Demand' => 'Minimalmenge',
'Annual Revenue' => 'Jahresumsatz',
'No Of Employees' => 'Mitarbeiteranzahl',
'Employees' =>'Mitarbeiter',
'Probability' => 'Wahrscheinlichkeit',
'Sales Commission' =>'Verkaufsprovision',
'Excise Duty' => 'Kommission',
'Budget Cost' => 'Budget Kosten',
'Actual Cost' => 'Aktuelle Kosten',
'Expected Revenue' => 'Erwarteter Umsatz',
'Expected Sales Count' => 'Erwartete Verkaufsanzahl',
'Actual Sales Count' => 'Aktuelle Verkaufsanzahl',
'Expected Response Count' => 'Erwartete Antwortanzahl',
'Actual Response Count' => 'Aktuelles Antwortanzahl',
'TargetSize' => 'Zielmenge',
'Expected ROI' => 'erwartetes ROI',
'Num Sent' => 'Anzahl gesendet',
'Actual ROI' => 'Aktuelles ROI',
'Ascending' => 'aufsteigend',
'Descending' => 'absteigend',
//Added for Notification
'Dear_Admin_tasks_not_been_completed' => 'Hallo Admin,<br><br> Bitte nehmen Sie zur Kenntnis, dass es Aufgaben gibt, die 24h nach Ihrem Fertigstellungstermins noch nicht erledigt sind.<br>',
'Task_sign'=>'Danke<br>HelpDesk Team<br>',
//Added for PDF notification
'LBL_PDF'=>'PDF kann nicht erzeugt werden, da die Seite zu breit ist. ',
//Added for pdf internalization in 5.0.4
'Thank You'=>'Danke',
'For Your Business'=>'für Ihr Vertauen',
'Subtotal'=>'Zwischensumme',
'Tax'=>'Mwst.',
'Adjustment'=>'Anpassung',
'Total'=>'Gesamtsumme',
'Description'=>'Beschreibung',
'Terms & Conditions'=>'AGB',
'Instructions'=>'Vorgaben',
'Total Due'=>'Total',
'Detach_Info'=>'Bei Zahlung mit Check, bitte an der oberen Linie abtrennen und mitsenden.',
'Billing Address'=>'Rechnungsadresse',
'Order Number'=>'Bestellnummer',
'Contact Name'=>'Kontaktname',
'Vendor Name'=>'Lieferantenname',
'Due Date'=>'fällig',
'Issue Date'=>'Erstelldatum',
'Shipping Address'=>'Lieferadresse',
'Page'=>'Seite',
'Tracking No.'=>'Trackingnr.',
'Req. No.'=>'Bedarfsnr.',
'Customer Name'=>'Kundenname',
'SO Number'=>'Bestellnr.',
'Account Number'=>'Kontonr.',
'Valid Till'=>'gültig bis',
'Quote Number'=>'Angebotsnr.',
'Invoice Number'=>'Rechnungsnr.',
'Product Code'=>'Produktcode',
'Qty'=>'Menge',
'Price'=>'Preis',
'Discount'=>'Rabatt',
'LBL_ADD_BUTTON' => 'erstelle',

// Added after 5.0.4 GA

//Added to Fix i18N issue in Email Template
'LBL_GENERAL_FIELDS'=>'Allgemeine Felder', 
//For Users fields
'HomePhone'=>'Telefon privat',
'Signature'=>'Signatur',
'Street'=>'Strasse',
'State'=>'Bundeland',
'Country'=>'Land',
'PostalCode'=>'PLZ',
//For General fields
'Current Date'=>'heutiges Datum',
'Current Time'=>'jetzige Zeit',

//Added for Role based Custom filters
'LBL_PUBLIC'=>'öffentlich',
'LBL_PENDING'=>'unerledigt',
'LBL_OTHERS'=>'andere',

//For Configuring/Using PurchaseOrder number
'PO Number'=>'PO Number',
'MSG_AUTO_GEN_ON_SAVE'=>'AUTOMATISCHE NUMMERVERGABE BEIM SPEICHERN',

//For Duplicate merging feature
'LBL_MERGE' => 'Merge',
'LBL_MERGE_BUTTON_TITLE' => 'Zusammenführen',
'LBL_SAVE_MERGE_BUTTON_TITLE' => 'Duplikate suchen',
'LBL_SELECT_MERGECRITERIA_HEADER' => 'Auswahl der Kriterien',
'LBL_SELECT_AS_PARENT' => '(primären Datensatz auswählen)',
'LBL_SELECT_MERGECRITERIA_TEXT' => 'Wählen Sie die Felder in denen nach Duplikaten gesucht werden soll',
'LBL_MERGE_SHOULDHAVE_INFO' => 'Bitte wenigstens ein Feld ausählen',
'LBL_FIND_DUPLICATES'=>'Duplikate suchen',
'LBL_NO_RECORD'=>'keine Daten verfügbar',
'LBL_NO_DUPLICATE' => 'keine Duplikate vorhanden',
'LBL_LAST_IMPORTED' => 'zuletzt importiert',
'LBL_NOW_IMPORTED'=>'importiert',
'LBL_EXISTING'=> 'existierend',
'LBL_TABLE_CREATED'=>'Tabelle wurde erfolgreich erzeugt',
'LBL_AVAILABLE_FIELDS'=>'vorhandene Felder',
'LBL_SELECTED_FIELDS'=>' die zu untersuchenden Felder',
'LBL_MERGE_SELECT'=>'Datensätze auswählen (max: 3)',
'DuplicatesHandling' => 'Bearbeitung von Duplikaten',
'LBL_DESC_FOR_MERGE_FIELDS' => 'Die primären Daten bleiben erhalten. Sie können eine Spalte dafür auswählen. Der andere Datensatz wird gelöscht, aber die ausgewählten Informationen bleiben erhalten.',
'LBL_DUPLICATE_MERGING' => 'Duplikate Zusammenführen',
'LBL_SELECT_TO_ENABLE_MERGING' => 'Wählen Sie diese Option um die Kriterien zum Zusammenführen festzulegen',

// Local Backup Feature
'LBL_BACKEDUPSUCCESSFULLY_TO_FILE' => 'backup erfolgreich',//BACKUP
'APP.LBL_NOW'=>'jetzt',//BACKUP
'LBL_NOW'=>'jetzt',//BACKUP

// Multi-Currency Customization
'LBL_MORE_CURRENCIES'=>'weitere Währungen',
'LBL_BASE_CURRENCY'=>'Basiswährung',
'LBL_CURRENCY'=>'Währung',
'LBL_PRICE'=>'Preis',
'LBL_CONVERSION_RATE'=>'Wechselkurs',
'LBL_RESET_PRICE'=>'Preis zurücksetzen',
'LBL_RESET'=>'zurücksetzen',
'LBL_UNIT_PRICE_NOT_PERMITTED'=>'Ihnen wurde der Zugang zu den Produktpreisen gesperrt.',

// Documents module
'SINGLE_Documents' => 'Dokument',
'LBL_NEW_NOTE' => 'neues Dokument',
'Documents' => 'Dokumente',
'Document' => 'Dokument',
'LBL_NOTE' => 'Dokument',
'LBL_CREATING_NEW_Documents' => 'neues Dokument erstellen',
'LBL_PLATFORM_INDEPENDENT'=>'Plattform unabhängig',
'Attachments' => 'Dokumente', //added for list header label in related lists
'LBL_HIDE'=>'verberge',

// Layout Editor and Ease navigation between records in Detail view
'LNK_LIST_NEXT' => 'weiter',
'LNK_LIST_PREVIOUS' => 'zurück',
'LBL_JUMP_BTN'=> 'SPRINGE',

'LBL_ASSIGN_BUTTON_LABEL'=>'Felder zuordnen',

// Mass Edit Feature
'LBL_MASS_EDIT'=>'Massenbearbeitung',
'LBL_MASSEDIT_FORM_HEADER'=>'Massenbearbeitung - Eingabefelder',

// Product Bundles
'Product Bundles'=>'Produktbündel',

// vtlib customization: Language strings
'VTLIB_MOD_NOT_ACTIVE' => ' Modul ist nicht aktiv!',
// END

// vtiger News & Feedback
'LBL_VTIGER_NEWS'=>'vtiger News',
'LBL_FEEDBACK'=>'Feedback',
// END

//added for asterisk integration
'CallHistory'=>'Anrufhistorie',
'PBXManager'=>'PBX Manager',
'LBL_OUTGOING_CALL_MESSAGE'=>'Wählen Sie eine Telefonnummer für den Anruf',
'LBL_OUTGOING_CALL'=>'raus gehender Anruf',
'LBL_OPERATION_NOT_SUPPORTED'=>'Diese Operation wird ggw. nicht unterstützt',
'LBL_ASTERISK_SET_ERROR'=>'Die Asterisk Server Details wurden nicht eingerichtet. Sie müssen diese zuerst konfigurieren.',
'LBL_CREATE_LEAD'=>'Lead erstellen',
'LBL_CREATE_CONTACT'=>'Person erstellen',
'LBL_CREATE_ACCOUNT'=>'Organisation erstellen',
'LBL_CREATE_TICKET'=>'Ticket erstellen',
'LBL_INCOMING_CALL'=>'eingehender Anruf',
'LBL_CALLER_INFORMATION'=>'Information über Anrufer',
'LBL_CALLER_NUMBER'=>'Nummer:',
'LBL_CALLER_NAME'=>'Name :',
'LBL_INFORMATION_VTIGER'=>'Information von Vtiger',

//asterisk integration ends

// Module Sequence Numbering
'LBL_DUPLICATE' => 'Kopiere',
'LBL_CLICK' => 'Klick',
'LBL_TO_CONFIGURE' => 'zur Konfiguration von',

// For Privacy Policy
'LNK_PRIVACY_POLICY'=>'Datenschutz',
'LBL_MOVE_BLOCK_FIELD' => 'Felder verschieben',
 
//added for find duplicate
'LBL_DUPLICATE_DATA_IN'=>'Duplikate ',
'LBL_DELETE'=>'Löschen',
'LBL_MERGE_SELECT'=>'ausgewählte Zusammenführen',
'LBL_MERGE_DATA_IN'=>'Zusammenführen von',
'LBL_MERGE'=>'Zusammenführen',
'LBL_ACTION'=>'Aktion',
'LBL_FIELDLISTS'=> 'Liste der Felder',
'LBL_RECORD'=>'Datensatznr.',
'LBL_DUP_PERMISSION' => 'Sie haben keine Löscherlaubnis für ',
'recordid' => 'Datensatznr.',
'Entity Type' => 'Typ',

// gmailbookmarklet customization
'LBL_GMAIL'=>'Gmail',
'LBL_BOOKMARKLET'=>'Bookmarklet',
// END

//ADDED for REPORTS CUSTOMIZING
'PRIVATE_FILTER'=>'privat',
'SHARE_FILTER'=>'veröffentlichen',
'PUBLIC_FILTER'=>'öffentlich',

// Account Hierarchy
'LBL_ACCOUNT_HIERARCHY' => 'Unternehmenshierarchie', 

//Prod Bundles
'LBL_NO_SUB_PRODUCTS'=>'kein Bündel',

//Custom Fields support for Calendar
'LBL_ACTIVITY_TYPE'=>'Aktivitätentyp',

// Services model
'LBL_ADD_SERVICE'=>'Dienstleistung hinzufügen',
'LBL_ITEM_DETAILS'=>'Details',
'LBL_ITEM_NAME'=>'Name',
'LBL_SETTINGS'=>'Einstellungen',
'LAYOUT_EDITOR'=>'Layout Editor',
'CUSTOMFIELD_MAPPING'=>'benutzerdefinierte Felder zusammenführen',
'ADD_PORTAL'=>'zum Portal hinzufügen',
'LBL_FILE_INTEGRITY_CHECK'=>'Check die Integrität von dieser Datei',

//To handle plurals of module names
'Todos' => 'Aufgaben',

// For Popup reminder
'LBL_POSTPONE'=>'verschieben',

// Unified Search extended support
'LBL_SELECT_MODULES_FOR_SEARCH' => 'Modulauswahl zur Suche',
'LBL_SELECT_ALL' => 'Alle auswählen', 
'LBL_UNSELECT_ALL' => 'Alle abwählen',
'LBL_FIELD_FOR_COMPARISION' => 'Feld zum Vergleich',
'LBL_DONE' => ' erledigt ',

'LBL_NO_MODULES_TO_SELECT' => 'Operation abgelehnt. Kein Modul dafür verfügbar.',

'CANNOT_CONVERT' => 'Umwandlung nicht möglich',

// For note link on the detailview
'LBL_ADD_NOTE'=>'erstelle Notiz',

// For Layout Editor 
'LBL_UNHIDE_FIELDS'=>'Felder anzeigen',

// For Mass Edit
'LBL_SELECT_FIELDS_TO_UDPATE_WITH_NEW_VALUE'=>'Felder auswählen, die mit dem neuen Wert gefüllt werden sollen.',

'LBL_LOADING'=>'Lade...',

//Added for Sub Products
'Parent Product' => 'Hauptprodukt',

//Added for Service Contracts
'Service Contracts' => 'Service Verträge',
'ServiceContracts' => 'Serviceverträge',
'Services' => 'Services',
	'LBL_REFRESH' => 'Aktualisieren',
	'LBL_Reminder' => 'Erinnerung',
	'LBL_RESET_PASSWORD' => 'Password zurücksetzen',
	'LBL_PHP_UPGRADE' => 'Wir haben Ihre PHP Version geändert. Durch die neue API zur Verschlüssleung
		  ist Ihr Passwort nicht länger gültig. Bitte setzen Sie ein neues Passwort.',
	'LBL_RESET_PASSWORD_DESCRIPTION' => 'you can reset password for all users using a script and set it to thier respective
			  user names.',


'Assets' => 'Produktverwaltung',
'CustomerPortal' => 'Kundenportal',
'Comments' => 'Kommentare',
'ProjectMilestone' => 'Projektmeilenstein',
'ProjectTask' => 'Projektaufgabe',
'ProjectTeam' => 'Projekt Team',
'Project' => 'Projekte',
'Recycle Bin' => 'Papierkorb',
'SMSNotifier' => 'SMS',
'Tool Tip' => 'Kurzinfo',

'ERR_INVALID_SECONDARY_EMAIL_ADDRESS' => 'keine gültige zweite E-Mail-Adresse angegeben.',
'SECONDARY_EMAIL_FILED_IS' => "\' im sekundären E-Mail Feld ist ",
'LBL_CRITERIA_AND'=>'und',
'LBL_CRITERIA_OR'=>'oder',
'LBL_NEW_GROUP'=>'Neue Gruppe',
'LBL_DELETE_GROUP'=>'Gruppe löschen',
'LBL_NEW_CONDITION'=>'Neue Bedingung',
'LBL_ADVANCED_FILTER' => 'Erweiterte Suche',
'LBL_CHANGE'=>'Ändern',
'LBL_CHANGE_TITLE'=>'Ändern [Alt+C]',
'LBL_NEXT_BUTTON_LABEL' => 'Weiter',	  
);

$app_list_strings = array (
  'moduleList' => 
  array (
    'Home' => 'Startseite',
    'Dashboard' => 'Cockpit',
    'Leads' => 'Leads',
    'Contacts' => 'Personen',
    'Accounts' => 'Organisationen',
    'Potentials' => 'Potentiale',
    'Campaigns' => 'Kampagnen',
    'Emails' => 'E-Mails',
    'Activities' => 'Aktivitäten',
    'Products' => 'Produkte',
    'HelpDesk' => 'Trouble Tickets',
    'Faq' => 'Wissensbasis',
    'Calendar' => 'Kalender',
    'Quotes' => 'Angebote',
    'PurchaseOrder' => 'Einkaufsbestellung',
    'Invoice' => 'Rechnung',
    'Rss' => 'RSS',
    'Reports' => 'Berichte',
    'Vendors' => 'Lieferanten',
    'PriceBooks' => 'Preislisten',
    'SalesOrder' => 'Verkaufsbestellungen',
    'Portal' => 'Meine Seiten',
	
	// Added after 5.0.4 GA
    'Documents' => 'Dokumente',
  ),
  'opportunity_relationship_type_default_key' => 'Primary Decision Maker',
  'opportunity_relationship_type_dom' => 
  array (
    '' => '',
    'Primary Decision Maker' => 'Entscheider',
    'Business Decision Maker' => 'Geschäftsentscheider',
    'Business Evaluator' => 'Geschäftsbeurteiler',
    'Technical Decision Maker' => 'technischer Entscheider',
    'Technical Evaluator' => 'technischer Beurteiler',
    'Executive Sponsor' => 'Sponsor',
    'Influencer' => 'Berater',
    'Other' => 'andere',
  ),
  'case_relationship_type_default_key' => 'Primary Contact',
  'case_relationship_type_dom' => 
	array(
		''=>'',
		'Primary Contact'=>'Primärer Kontakt',
		'Alternate Contact'=>'Alternativer Kontakt',
		),
'task_priority_dom' =>
	array(
		'High'=>'hoch',
		'Medium'=>'mittel',
		'Low'=>'niedrig',
		),
'task_status_dom' =>
	array(
		'Planned'=>'geplant',
		'Completed'=>'abgeschlossen',
		'Deferred'=>'verschoben',
		),
'meeting_status_dom' =>
	array(
		'Planned'=>'geplant',
		'Held'=>'durchgeführt',
		'Not Held'=>'nicht durchgeführt',
		),
'call_status_dom' =>
	array(
		'Planned'=>'geplant',
		'Held'=>'durchgeführt',
		'Not Held'=>'nicht durchgeführt',
		),
'case_status_default_key' => 'New',
'case_status_dom' =>
	array(
		'New'=>'neu',
		'Assigned'=>'zugewiesen',
		'Closed'=>'abgeschlossen',
		'Pending Input'=>'erwarte Zuarbeit',
		'Rejected'=>'zurückgewiesen',
		),
'user_status_dom' =>
	array(
		'Active'=>'aktiv',
		'Inactive'=>'inaktiv',
		),
'record_type_default_key' => 'Accounts',
'record_type_display' =>
	array(
		'Accounts' => 'Organisationen',
		'Leads' => 'Lead',
		'Opportunities' => 'Potentiale',
),

); 

// Translation for currency names
$app_currency_strings = array(
	'Albania, Leke' 		=> 'Albanien, Leke',
	'Argentina, Pesos' 		=> 'Argentinien, Pesos',
	'Aruba, Guilders' 		=> 'Aruba, Guilders',
	'Australia, Dollars' 	=> 'Australien, Dollars',
	'Azerbaijan, New Manats'=> 'Azerbaijan, New Manats',
	'Bahamas, Dollars' 		=> 'Bahamas, Dollars',
	'Bahrain, Dinar' 		=> 'Bahrain, Dinar',
	'Barbados, Dollars' 	=> 'Barbados, Dollars',
	'Belarus, Rubles' 		=> 'Belarus, Rubles',
	'Belize, Dollars' 		=> 'Belize, Dollars',
	'Bermuda, Dollars' 		=> 'Bermuda, Dollars',
	'Bolivia, Bolivianos' 	=> 'Bolivia, Bolivianos',
	'Convertible Marka'		=> 'Convertible Marka',
	'Botswana, Pulas' 		=> 'Botswana, Pulas',
	'Bulgaria, Leva' 		=> 'Bulgarien, Leva',
	'Brazil, Reais' 		=> 'Brasilien, Reais',
	'Great Britain Pounds' 	=> 'England, Pounds',
	'Brunei Darussalam, Dollars' => 'Brunei Darussalam, Dollars',
	'Canada, Dollars' 		=> 'Kanada, Dollars',
	'Cayman Islands, Dollars' => 'Cayman Islands, Dollars',
	'Chile, Pesos' 			=> 'Chile, Pesos',
	'Colombia, Pesos' 		=> 'Colombia, Pesos',
	'Costa Rica, ColÃ³n' 	=> 'Costa Rica, ColÃ³n',
	'Croatia, Kuna' 		=> 'Croatia, Kuna',
	'Cuba, Pesos' 			=> 'Cuba, Pesos',
	'Czech Republic, Koruny' => 'Czech Republic, Koruny',
	'Denmark, Kroner' 		=> 'Denmark, Kroner',
	'Dominican Republic, Pesos' => 'Dominican Republic, Pesos',
	'East Caribbean, Dollars' => 'East Caribbean, Dollars',
	'Egypt, Pounds' 		=> 'Egypt, Pounds',
	'El Salvador, Colones' 	=> 'El Salvador, Colones',
	'England, Pounds' 		=> 'England, Pounds',
	'Estonia, Krooni' 		=> 'Estonia, Krooni',
	'Euro' 					=> 'Euro',
	'Falkland Islands, Pounds' => 'Falkland Islands, Pounds',
	'Fiji, Dollars' => 'Fiji, Dollars',
	'Ghana, Cedis' 	=> 'Ghana, Cedis',
	'Gibraltar, Pounds' 	=> 'Gibraltar, Pounds',
	'Guatemala, Quetzales' 	=> 'Guatemala, Quetzales',
	'Guernsey, Pounds' 		=> 'Guernsey, Pounds',
	'Guyana, Dollars' 		=> 'Guyana, Dollars',
	'Honduras, Lempiras' 	=> 'Honduras, Lempiras',
	'LvHong Kong, Dollars ' => 'LvHong Kong, Dollars ',
	'Hungary, Forint' 		=> 'Hungary, Forint',
	'Iceland, Krona' 		=> 'Iceland, Krona',
	'India, Rupees' 		=> 'India, Rupees',
	'Indonesia, Rupiahs' 	=> 'Indonesia, Rupiahs',
	'Iran, Rials' 			=> 'Iran, Rials',
	'Isle of Man, Pounds' 	=> 'Isle of Man, Pounds',
	'Israel, New Shekels' 	=> 'Israel, New Shekels',
	'Jamaica, Dollars' 		=> 'Jamaica, Dollars',
	'Japan, Yen' 			=> 'Japan, Yen',
	'Jersey, Pounds' 		=> 'Jersey, Pounds',
	'Kazakhstan, Tenge' 	=> 'Kazakhstan, Tenge',
	'Korea (North), Won' 	=> 'Korea (North), Won',
	'Korea (South), Won' 	=> 'Korea (South), Won',
	'Kyrgyzstan, Soms' 		=> 'Kyrgyzstan, Soms',
	'Laos, Kips' 			=> 'Laos, Kips',
	'Latvia, Lati' 			=> 'Latvia, Lati',
	'Lebanon, Pounds' 		=> 'Lebanon, Pounds',
	'Liberia, Dollars' 		=> 'Liberia, Dollars',
	'Switzerland Francs' 	=> 'Switzerland Francs',
	'Lithuania, Litai' 		=> 'Lithuania, Litai',
	'Macedonia, Denars' 	=> 'Macedonia, Denars',
	'Malaysia, Ringgits' 	=> 'Malaysia, Ringgits',
	'Mauritius, Rupees' 	=> 'Mauritius, Rupees',
	'Mexico, Pesos' 		=> 'Mexico, Pesos',
	'Mongolia, Tugriks' 	=> 'Mongolia, Tugriks',
	'Mozambique, Meticais' 	=> 'Mozambique, Meticais',
	'Namibia, Dollars' 		=> 'Namibia, Dollars',
	'Nepal, Rupees' 		=> 'Nepal, Rupees',
	'Netherlands Antilles, Guilders' => 'Netherlands Antilles, Guilders',
	'New Zealand, Dollars' 	=> 'New Zealand, Dollars',
	'Nicaragua, Cordobas' 	=> 'Nicaragua, Cordobas',
	'Nigeria, Nairas' 		=> 'Nigeria, Nairas',
	'North Korea, Won' 		=> 'North Korea, Won',
	'Norway, Krone' 		=> 'Norway, Krone',
	'Oman, Rials' 			=> 'Oman, Rials',
	'Pakistan, Rupees' 		=> 'Pakistan, Rupees',
	'Panama, Balboa' 		=> 'Panama, Balboa',
	'Paraguay, Guarani' 	=> 'Paraguay, Guarani',
	'Peru, Nuevos Soles' 	=> 'Peru, Nuevos Soles',
	'Philippines, Pesos' 	=> 'Philippines, Pesos',
	'Poland, Zlotych' 		=> 'Poland, Zlotych',
	'Romania, New Lei' 		=> 'Romania, New Lei',
	'Russia, Rubles'		=> 'Russia, Rubles',
	'Saint Helena, Pounds' => 'Saint Helena, Pounds',
	'Saudi Arabia, Riyals' => 'Saudi Arabia, Riyals',
	'Serbia, Dinars' 		=> 'Serbia, Dinars',
	'Seychelles, Rupees' 	=> 'Seychelles, Rupees',
	'Singapore, Dollars' 	=> 'Singapore, Dollars',
	'Solomon Islands, Dollars' => 'Solomon Islands, Dollars',
	'Somalia, Shillings' => 'Somalia, Shillings',
	'South Africa, Rand' => 'South Africa, Rand',
	'South Korea, Won' 	=> 'South Korea, Won',
	'Sri Lanka, Rupees' => 'Sri Lanka, Rupees',
	'Sweden, Kronor' 	=> 'Sweden, Kronor',
	'Switzerland, Francs' => 'Switzerland, Francs',
	'Suriname, Dollars' 	=> 'Suriname, Dollars',
	'Syria, Pounds' 		=> 'Syria, Pounds',
	'Taiwan, New Dollars' 	=> 'Taiwan, New Dollars',
	'Thailand, Baht' 		=> 'Thailand, Baht',
	'Trinidad and Tobago, Dollars' => 'Trinidad and Tobago, Dollars',
	'Turkey, New Lira' 		=> 'Turkey, New Lira',
	'Turkey, Liras' 		=> 'Turkey, Liras',
	'Tuvalu, Dollars' 		=> 'Tuvalu, Dollars',
	'Ukraine, Hryvnia' 		=> 'Ukraine, Hryvnia',
	'United Kingdom, Pounds' => 'United Kingdom, Pounds',
	'USA, Dollars' 			=> 'USA, Dollars',
	'Uruguay, Pesos' 		=> 'Uruguay, Pesos',
	'Uzbekistan, Sums' 		=> 'Uzbekistan, Sums',
	'Venezuela, Bolivares Fuertes' => 'Venezuela, Bolivares Fuertes',
	'Vietnam, Dong' 		=> 'Vietnam, Dong',
	'Zimbabwe Dollars' 		=> 'Zimbabwe Dollars',
	'China, Yuan Renminbi' 	=> 'China, Yuan Renminbi',
	'Afghanistan, Afghanis' => 'Afghanistan, Afghanis',
	'Cambodia, Riels' 		=> 'Cambodia, Riels',
	'China, Yuan Renminbi' => 'China, Yuan Renminbi',
	'Jordan, Dinar' => 'Jordan, Dinar',
	'Kenya, Shilling' => 'Kenya, Shilling',
	'MADAGASCAR, Malagasy Ariary' => 'MADAGASCAR, Malagasy Ariary',
	'United Arab Emirates, Dirham' => 'United Arab Emirates, Dirham',
	'United Republic OF Tanzania, Shilling' => 'United Republic OF Tanzania, Shilling',
	'Zambia, Kwacha' => 'Zambia, Kwacha',
	'Malawi, kwacha'		=> 'Malawi, kwacha',
	'Tunisian, Dinar'		=> 'Tunisian, Dinar',
	'Moroccan, Dirham'		=> 'Moroccan, Dirham',
);
?>